=================
zyte-common-items
=================

.. image:: https://img.shields.io/pypi/v/zyte-common-items.svg
   :target: https://pypi.python.org/pypi/zyte-common-items
   :alt: PyPI Version

.. image:: https://img.shields.io/pypi/pyversions/zyte-common-items.svg
   :target: https://pypi.python.org/pypi/zyte-common-items
   :alt: Supported Python Versions

.. image:: https://github.com/zytedata/zyte-common-items/workflows/tox/badge.svg
   :target: https://github.com/zytedata/zyte-common-items/actions
   :alt: Build Status

.. image:: https://codecov.io/github/zytedata/zyte-common-items/coverage.svg?branch=master
   :target: https://codecov.io/gh/zytedata/zyte-common-items
   :alt: Coverage report

.. description starts

``zyte-common-items`` is a Python 3.8+ library of item_ and `page object`_
classes for web data extraction that we use at Zyte_ to maximize opportunities
for code reuse.

.. _item: https://docs.scrapy.org/en/latest/topics/items.html
.. _page object: https://web-poet.readthedocs.io/en/stable/
.. _Zyte: https://www.zyte.com/

.. description ends

* Documentation: https://zyte-common-items.readthedocs.io/en/latest/
* License: BSD 3-clause
